==> v1.0.1.tar.gz: zyos_go_o2o_business/o2o/add_store_fans.go <==
package o2o

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db/model"
	zhios_o2o_business_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/utils"
	zhios_o2o_business_logx "code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/utils/logx"
	"time"
	"xorm.io/xorm"
)

//通过上级查询是否商家,绑定关系
func GetParentUidToBindFans(eg *xorm.Engine, uid, parentUid string) {
	manager := GetO2oStore(eg, parentUid)
	if manager == nil {
		return
	}
	DealCommonPayStoreFans(eg, uid, zhios_o2o_business_utils.IntToStr(manager.Id), "0", "拉新", "1")
}
func GetO2oStore(eg *xorm.Engine, parentUid string) *model.O2oStore {
	merchantList, err := db.MerchantFindByUId(eg, parentUid)
	if err != nil || merchantList == nil {
		return nil
	}
	manager, err := db.MerchantFindByStoreManager(eg, zhios_o2o_business_utils.IntToStr(merchantList.Id))
	if err != nil || manager == nil {
		return nil
	}
	return manager
}

//DealCommonPayStoreFans 處理通用支付中的店鋪粉絲
/***
uid 用户id
storeId o2o_store的 id
isUpdate 0只新增 1可修改
remake 备注
types 0消费者  1拉新粉丝
*/
func DealCommonPayStoreFans(eg *xorm.Engine, uid string, storeId, isUpdate, remake, types string) {
	storeFans, err := db.GetStoreFansByUid(eg, uid, storeId)
	if storeFans == nil {
		var insertData = model.O2oStoreFans{
			UserId:     zhios_o2o_business_utils.StrToInt(uid),
			StoreId:    zhios_o2o_business_utils.StrToInt(storeId),
			Remake:     remake,
			CreateTime: time.Now(),
			UpdateTime: time.Now(),
			Type:       zhios_o2o_business_utils.StrToInt(types),
		}
		err = db.StoreFansInsertOne(eg, &insertData)
	} else if isUpdate == "1" {
		storeFans.OrderNum++
		err = db.UpdateStoreFans(eg, storeFans)
	}
	if err != nil {
		zhios_o2o_business_logx.Warn(err, "處理通用支付中的店鋪粉絲-失敗！")
	}
}

==> v1.0.9.tar.gz: zyos_go_o2o_business/o2o/add_store_fans.go <==
package o2o

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db/model"
	zhios_o2o_business_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/utils"
	"time"
	"xorm.io/xorm"
)

//通过上级查询是否商家,绑定关系
func GetParentUidToBindFans(eg *xorm.Engine, uid, parentUid string) {
	_, manager := GetO2oStore(eg, parentUid)
	if manager == nil {
		return
	}
	DealCommonPayStoreFans(eg, uid, zhios_o2o_business_utils.IntToStr(manager.Id), "0", "拉新", "1")
}
func GetO2oStore(eg *xorm.Engine, parentUid string) (*model.O2oMerchant, *model.O2oStore) {
	merchantList, err := db.MerchantFindByUId(eg, parentUid)
	if err != nil || merchantList == nil {
		return nil, nil
	}
	manager, err := db.MerchantFindByStoreManager(eg, zhios_o2o_business_utils.IntToStr(merchantList.Id))
	if err != nil || manager == nil {
		return nil, nil
	}
	return merchantList, manager
}

//DealCommonPayStoreFans 處理通用支付中的店鋪粉絲
/***
uid 用户id
storeId o2o_store的 id
isUpdate 0只新增 1可修改
remake 备注
types 0消费者  1拉新粉丝
*/
func DealCommonPayStoreFans(eg *xorm.Engine, uid string, storeId, isUpdate, remake, types string) {
	storeFans, err := db.GetStoreFansByUid(eg, uid, storeId)
	if storeFans == nil {
		var insertData = model.O2oStoreFans{
			UserId:     zhios_o2o_business_utils.StrToInt(uid),
			StoreId:    zhios_o2o_business_utils.StrToInt(storeId),
			Remake:     remake,
			CreateTime: time.Now(),
			UpdateTime: time.Now(),
			Type:       zhios_o2o_business_utils.StrToInt(types),
		}
		err = db.StoreFansInsertOne(eg, &insertData)
	} else if isUpdate == "1" {
		storeFans.OrderNum++
		err = db.UpdateStoreFans(eg, storeFans)
	}
	if err != nil {
	}
}
